@@ -15,6 +15,8 @@ use NewsExtractor::SiteSpecificExtractor::www_peopo_org;
 use NewsExtractor::SiteSpecificExtractor::www_ntdtv_com;
 use NewsExtractor::SiteSpecificExtractor::www_ksnews_com_tw;
 use NewsExtractor::SiteSpecificExtractor::news_tvbs_com_tw;
+use NewsExtractor::SiteSpecificExtractor::money_udn_com;
+use NewsExtractor::SiteSpecificExtractor::www_taipeitimes_com;
 
 has extractor => (
     required => 0,
@@ -38,8 +40,18 @@ use constant {
         'www.ntdtv.com' => 'NewsExtractor::SiteSpecificExtractor::www_ntdtv_com',
         'www.ksnews.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_ksnews_com_tw',
         'news.tvbs.com.tw' => 'NewsExtractor::SiteSpecificExtractor::news_tvbs_com_tw',
+        'stars.udn.com' => 'NewsExtractor::SiteSpecificExtractor::money_udn_com',
+        'money.udn.com' => 'NewsExtractor::SiteSpecificExtractor::money_udn_com',
+        'house.udn.com' => 'NewsExtractor::SiteSpecificExtractor::money_udn_com',
+        'www.taipeitimes.com' => 'NewsExtractor::SiteSpecificExtractor::www_taipeitimes_com',
     },
     CSSRuleSetByHost => {
+        'udn.com' => {
+            headline   => '#story_art_title',
+            dateline   => '.story_bady_info_author > span:nth-child(1)',
+            journalist => '.story_bady_info_author > a:nth-child(2)',
+            content_text => 'div#article_body',
+        },
         'www.nownews.com' => {
             headline   => 'h1.entry-title',
             dateline   => 'span.td-post-date:nth-child(2) > time:nth-child(1)',
